@@ -80,7 +80,7 @@ LOGGING_CONFIG = {
 
 logging.config.dictConfig(LOGGING_CONFIG)
 
-COMMAND_GET_ALL_COMMITS_SHA = "git log {} --pretty=format:%H"
+COMMAND_GET_ALL_COMMITS_SHA = "git log --pretty=format:%H {} --"
 COMMAND_COMMIT = "git show --reverse --first-parent --raw --numstat --abbrev=40 --full-index -p -M --pretty=format:'Commit:\t%H%nDate:\t%ai%nTree:\t%T%nParents:\t%P%nAuthor:\t%an\t%ae\t%ai%nCommitter:\t%cn\t%ce\t%ci%nMessage:\t%s%n' {}"
 COMMAND_COMMIT_BRANCH = "git branch --contains {}"
 COMMAND_COMMIT_FILE_BLAME = "git blame {}^ -L {},{} -- {}"
